@@ -1,26 +1,11 @@
 /*
     This file is part of the kxmlrpc library.
+    SPDX-FileCopyrightText: 2006 Narayan Newton <narayannewton@gmail.com>
 
-    Copyright (c) 2006 Narayan Newton <narayannewton@gmail.com>
-
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Library General Public
-    License as published by the Free Software Foundation; either
-    version 2 of the License, or (at your option) any later version.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Library General Public License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to
-    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-    Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include <QTest>
-#include <QDebug>
 
 #include "querytest.h"
 
@@ -51,6 +36,7 @@ void QueryTest::testMarkupCall_data()
     QTest::addColumn<QList<QVariant>>("arguments");
     QTest::addColumn<QByteArray>("xml");
 
+    /* clang-format off */
     QTest::newRow("int") << QString::fromLatin1("MyMethod")
                          << (QVariantList() << 1)
                          << XML_CALL_HEAD("MyMethod")
@@ -138,6 +124,7 @@ void QueryTest::testMarkupCall_data()
                             "</struct></value>\r\n"
                             "</param>\r\n"
                             XML_CALL_END;
+    /* clang-format on */
 }
 
 void QueryTest::testMarkupCall()
@@ -159,80 +146,59 @@ void QueryTest::testResponse_data()
     QVariantMap map;
     map[QLatin1String("faultCode")] = 10;
     map[QLatin1String("faultString")] = QLatin1String("Fatal Server Error");
+
+    /* clang-format off */
     QTest::newRow("fault") << false
                            << XML_FAULT_HEAD
-                              "<value><struct>"
-                              "<member><name>faultCode</name><value><int>10</int></value></member>"
-                              "<member><name>faultString</name><value><string><![CDATA[Fatal Server Error]]></string></value></member>"
-                              "</struct></value>"
-                              XML_FAULT_END
+        "<value><struct>"
+        "<member><name>faultCode</name><value><int>10</int></value></member>"
+        "<member><name>faultString</name><value><string><![CDATA[Fatal Server Error]]></string></value></member>"
+        "</struct></value>" XML_FAULT_END
                            << (QVariantList() << map);
 
     QTest::newRow("string") << true
                             << XML_RESPONSE_HEAD
-                               "<param>"
-                               "<value><STRING><![CDATA[result]]></STRING></value>"
-                               "</param>"
-                               XML_RESPONSE_END
+        "<param>"
+        "<value><STRING><![CDATA[result]]></STRING></value>"
+        "</param>" XML_RESPONSE_END
                             << (QVariantList() << QLatin1String("result"));
     QTest::newRow("int") << true
                          << XML_RESPONSE_HEAD
-                            "<param>"
-                            "<value><INT>1</INT></value>"
-                            "</param>"
-                            XML_RESPONSE_END
+        "<param>"
+        "<value><INT>1</INT></value>"
+        "</param>" XML_RESPONSE_END
                          << (QVariantList() << 1);
-    QTest::newRow("i4") << true
-                        << XML_RESPONSE_HEAD
-                           "<param><value><I4>42</I4></value></param>"
-                           XML_RESPONSE_END
-                        << (QVariantList() << 42);
-    QTest::newRow("boolean (num)") << true
-                                   << XML_RESPONSE_HEAD
-                                      "<param><value><BOOLEAN>1</BOOLEAN></value></param>"
-                                      XML_RESPONSE_END
+    QTest::newRow("i4") << true << XML_RESPONSE_HEAD "<param><value><I4>42</I4></value></param>" XML_RESPONSE_END << (QVariantList() << 42);
+    QTest::newRow("boolean (num)") << true << XML_RESPONSE_HEAD "<param><value><BOOLEAN>1</BOOLEAN></value></param>" XML_RESPONSE_END
                                    << (QVariantList() << true);
-    QTest::newRow("boolean (str)") << true
-                                   << XML_RESPONSE_HEAD
-                                      "<param><value><BOOLEAN>TruE</BOOLEAN></value></param>"
-                                      XML_RESPONSE_END
+    QTest::newRow("boolean (str)") << true << XML_RESPONSE_HEAD "<param><value><BOOLEAN>TruE</BOOLEAN></value></param>" XML_RESPONSE_END
                                    << (QVariantList() << true);
-    QTest::newRow("base64") << true
-                            << XML_RESPONSE_HEAD
-                               "<param><value><BASE64>VmFsaWQgcmVzcG9uc2UK</BASE64></value></param>"
-                               XML_RESPONSE_END
+    QTest::newRow("base64") << true << XML_RESPONSE_HEAD "<param><value><BASE64>VmFsaWQgcmVzcG9uc2UK</BASE64></value></param>" XML_RESPONSE_END
                             << (QVariantList() << QByteArray("Valid response\n"));
-    QTest::newRow("datetime") << true
-                              << XML_RESPONSE_HEAD
-                                 "<param><value><DATETIME>2015-01-05T18:02:22</DATETIME></value></param>"
-                                 XML_RESPONSE_END
+    QTest::newRow("datetime") << true << XML_RESPONSE_HEAD "<param><value><DATETIME>2015-01-05T18:02:22</DATETIME></value></param>" XML_RESPONSE_END
                               << (QVariantList() << QDateTime(QDate(2015, 01, 05), QTime(18, 02, 22)));
     QTest::newRow("datetime 2") << true
-                                << XML_RESPONSE_HEAD
-                                   "<param><value><dateTime.iso8601>2015-01-05T17:03:15Z</dateTime.iso8601></value></param>"
-                                   XML_RESPONSE_END
+                                << XML_RESPONSE_HEAD "<param><value><dateTime.iso8601>2015-01-05T17:03:15Z</dateTime.iso8601></value></param>" XML_RESPONSE_END
                                 << (QVariantList() << QDateTime(QDate(2015, 01, 05), QTime(17, 03, 15), Qt::UTC));
     QTest::newRow("array") << true
                            << XML_RESPONSE_HEAD
-                              "<param><value><ARRAY><data>"
-                              "<value><STRING><![CDATA[item 1]]></STRING></value>"
-                              "<value><STRING><![CDATA[item 2]]></STRING></value>"
-                              "</data></ARRAY></value></param>"
-                              XML_RESPONSE_END
-                           << (QVariantList() << QVariant(QVariantList() << QLatin1String("item 1")
-                                                                         << QLatin1String("item 2")));
+        "<param><value><ARRAY><data>"
+        "<value><STRING><![CDATA[item 1]]></STRING></value>"
+        "<value><STRING><![CDATA[item 2]]></STRING></value>"
+        "</data></ARRAY></value></param>" XML_RESPONSE_END
+                           << (QVariantList() << QVariant(QVariantList() << QLatin1String("item 1") << QLatin1String("item 2")));
 
     map.clear();
     map[QLatin1String("Key 1")] = 15;
     map[QLatin1String("Key 2")] = QLatin1String("Value");
     QTest::newRow("struct") << true
                             << XML_RESPONSE_HEAD
-                               "<param><value><STRUCT>"
-                               "<member><name>Key 1</name><value><I4>15</I4></value></member>"
-                               "<member><name>Key 2</name><value><string><![CDATA[Value]]></string></value></member>"
-                               "</STRUCT></value></param>"
-                               XML_RESPONSE_END
+        "<param><value><STRUCT>"
+        "<member><name>Key 1</name><value><I4>15</I4></value></member>"
+        "<member><name>Key 2</name><value><string><![CDATA[Value]]></string></value></member>"
+        "</STRUCT></value></param>" XML_RESPONSE_END
                             << (QVariantList() << map);
+    /* clang-format on */
 }
 
 void QueryTest::testResponse()
@@ -262,3 +228,4 @@ void QueryTest::testResponse()
     }
 }
 
+#include "moc_querytest.cpp"
